summaryrefslogtreecommitdiffstatshomepage
diff options
context:
space:
mode:
author MooglyGuy <MooglyGuy@users.noreply.github.com>2021-07-15 08:56:28 +0200
committer GitHub <noreply@github.com>2021-07-15 16:56:28 +1000
commit61077d4ffbcd9f67c3b288257321215af60b2f45 (patch)
treeaab8e76027d92178b9cfda4c9e9fcc9c72477d52
parent3d84f1d99aeb9973ba245e3419fd603f7e580b98 (diff)
video/namco_c355spr.cpp: Adjusted sprite attribute table index mask to accommodate vshoot. (#8302) [Ryan Holtz]
-rw-r--r--src/mame/video/namco_c355spr.cpp2
1 files changed, 1 insertions, 1 deletions
diff --git a/src/mame/video/namco_c355spr.cpp b/src/mame/video/namco_c355spr.cpp
index f5e734952de..417914d9ecf 100644
--- a/src/mame/video/namco_c355spr.cpp
+++ b/src/mame/video/namco_c355spr.cpp
@@ -356,7 +356,7 @@ void namco_c355spr_device::get_single_sprite(const u16 *pSource, c355_sprite *sp
const u16 palette = pSource[6];
sprite_ptr->pri = ((palette >> 4) & 0xf);
- const u16 linkno = pSource[0] & 0x3ff; /* LINKNO 0x000..0x3ff for format table entry, verified in finalapr code */
+ const u16 linkno = pSource[0] & 0x7ff; /* LINKNO 0x000..0x7ff for format table entries - finalapr code masks with 0x3ff, but vshoot requires 0x7ff */
sprite_ptr->offset = pSource[1]; /* OFFSET */
int hpos = pSource[2]; /* HPOS 0x000..0x7ff (signed) */
int vpos = pSource[3]; /* VPOS 0x000..0x7ff (signed) */